@@ -9,6 +9,7 @@ from github.GithubException import GithubException
 from github.NamedUser import NamedUser
 from github.PaginatedList import PaginatedList
 from github.PullRequest import PullRequest
+from github.Repository import Repository
 
 from webhook_server.utils.constants import COMMAND_ADD_ALLOWED_USER_STR
 
@@ -20,8 +21,8 @@ class OwnersFileHandler:
     def __init__(self, github_webhook: "GithubWebhook") -> None:
         self.github_webhook = github_webhook
         self.logger = self.github_webhook.logger
-        self.log_prefix = self.github_webhook.log_prefix
-        self.repository = self.github_webhook.repository
+        self.log_prefix: str = self.github_webhook.log_prefix
+        self.repository: Repository = self.github_webhook.repository
 
     async def initialize(self, pull_request: PullRequest) -> "OwnersFileHandler":
         self.changed_files = await self.list_changed_files(pull_request=pull_request)
@@ -174,6 +175,7 @@ class OwnersFileHandler:
             for _approver in list_of_approvers.get("approvers", []):
                 _approvers.append(_approver)
 
+        _approvers = list(set(_approvers))
         _approvers.sort()
         self.logger.debug(f"{self.log_prefix} All pull request approvers: {_approvers}")
         return _approvers
@@ -186,6 +188,7 @@ class OwnersFileHandler:
             for _reviewer in list_of_reviewers.get("reviewers", []):
                 _reviewers.append(_reviewer)
 
+        _reviewers = list(set(_reviewers))
         _reviewers.sort()
         self.logger.debug(f"Pull request reviewers are: {_reviewers}")
         return _reviewers
@@ -238,23 +241,34 @@ class OwnersFileHandler:
     async def assign_reviewers(self, pull_request: PullRequest) -> None:
         self._ensure_initialized()
 
+        self.logger.step(f"{self.log_prefix} Starting reviewer assignment based on OWNERS files")  # type: ignore
         self.logger.info(f"{self.log_prefix} Assign reviewers")
 
         _to_add: list[str] = list(set(self.all_pull_request_reviewers))
         self.logger.debug(f"{self.log_prefix} Reviewers to add: {', '.join(_to_add)}")
 
+        if _to_add:
+            self.logger.step(f"{self.log_prefix} Assigning {len(_to_add)} reviewers to PR")  # type: ignore
+        else:
+            self.logger.step(f"{self.log_prefix} No reviewers to assign")  # type: ignore
+            return
+
         for reviewer in _to_add:
             if reviewer != pull_request.user.login:
                 self.logger.debug(f"{self.log_prefix} Adding reviewer {reviewer}")
                 try:
                     await asyncio.to_thread(pull_request.create_review_request, [reviewer])
+                    self.logger.step(f"{self.log_prefix} Successfully assigned reviewer {reviewer}")  # type: ignore
 
                 except GithubException as ex:
+                    self.logger.step(f"{self.log_prefix} Failed to assign reviewer {reviewer}")  # type: ignore
                     self.logger.debug(f"{self.log_prefix} Failed to add reviewer {reviewer}. {ex}")
                     await asyncio.to_thread(
                         pull_request.create_issue_comment, f"{reviewer} can not be added as reviewer. {ex}"
                     )
 
+        self.logger.step(f"{self.log_prefix} Reviewer assignment completed")  # type: ignore
+
     async def is_user_valid_to_run_commands(self, pull_request: PullRequest, reviewed_user: str) -> bool:
         self._ensure_initialized()
 
