@@ -1,14 +1,14 @@
 import asyncio
-import logging
 import os
 import tempfile
 from typing import Any
 from unittest.mock import AsyncMock, Mock, patch
 
 import pytest
+from simple_logger.logger import get_logger
 from starlette.datastructures import Headers
 
-from webhook_server.libs.exceptions import RepositoryNotFoundError
+from webhook_server.libs.exceptions import RepositoryNotFoundInConfigError
 from webhook_server.libs.github_api import GithubWebhook
 
 
@@ -61,7 +61,7 @@ class TestGithubWebhook:
     @pytest.fixture
     def minimal_hook_data(self) -> dict[str, Any]:
         return {
-            "repository": {"name": "repo", "full_name": "org/repo"},
+            "repository": {"name": "test-repo", "full_name": "org/test-repo"},
             "number": 1,
         }
 
@@ -70,14 +70,14 @@ class TestGithubWebhook:
         return {"X-GitHub-Event": "pull_request", "X-GitHub-Delivery": "abc"}
 
     @pytest.fixture
-    def logger(self) -> logging.Logger:
-        return logging.getLogger("test")
+    def logger(self):
+        return get_logger(name="test")
 
     @patch("webhook_server.libs.github_api.Config")
     @patch("webhook_server.libs.github_api.get_api_with_highest_rate_limit")
     @patch("webhook_server.libs.github_api.get_github_repo_api")
     @patch("webhook_server.libs.github_api.get_repository_github_app_api")
-    @patch("webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix")
+    @patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix")
     def test_init_success(
         self,
         mock_color,
@@ -94,41 +94,42 @@ class TestGithubWebhook:
         mock_get_api.return_value = (Mock(), "token", "apiuser")
         mock_get_repo_api.return_value = Mock(name="repo_api")
         mock_get_app_api.return_value = Mock()
-        mock_color.return_value = "repo"
+        mock_color.return_value = "test-repo"
         gh = GithubWebhook(minimal_hook_data, minimal_headers, logger)
-        assert gh.repository_name == "repo"
-        assert gh.repository_full_name == "org/repo"
+        assert gh.repository_name == "test-repo"
+        assert gh.repository_full_name == "org/test-repo"
         assert hasattr(gh, "repository")
         assert hasattr(gh, "repository_by_github_app")
         assert gh.log_prefix
 
     @patch("webhook_server.libs.github_api.Config")
     def test_init_missing_repo(self, mock_config, minimal_hook_data, minimal_headers, logger):
-        mock_config.return_value.repository = False
-        with pytest.raises(RepositoryNotFoundError):
+        mock_config.return_value.repository = "repo"
+        mock_config.return_value.repository_data = {}
+        with pytest.raises(RepositoryNotFoundInConfigError):
             GithubWebhook(minimal_hook_data, minimal_headers, logger)
 
     @patch("webhook_server.libs.github_api.Config")
     @patch("webhook_server.libs.github_api.get_api_with_highest_rate_limit")
-    @patch("webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix")
+    @patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix")
     def test_init_no_api_token(self, mock_color, mock_get_api, mock_config, minimal_hook_data, minimal_headers, logger):
         mock_config.return_value.repository = True
         mock_get_api.return_value = (None, None, None)
-        mock_color.return_value = "repo"
+        mock_color.return_value = "test-repo"
         gh = GithubWebhook(minimal_hook_data, minimal_headers, logger)
         assert not hasattr(gh, "repository")
 
     @patch("webhook_server.libs.github_api.Config")
     @patch("webhook_server.libs.github_api.get_api_with_highest_rate_limit")
     @patch("webhook_server.libs.github_api.get_github_repo_api")
-    @patch("webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix")
+    @patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix")
     def test_init_no_github_app_api(
         self, mock_color, mock_get_repo_api, mock_get_api, mock_config, minimal_hook_data, minimal_headers, logger
     ):
         mock_config.return_value.repository = True
         mock_get_api.return_value = (Mock(), "token", "apiuser")
         mock_get_repo_api.return_value = Mock()
-        mock_color.return_value = "repo"
+        mock_color.return_value = "test-repo"
         with patch("webhook_server.libs.github_api.get_repository_github_app_api", return_value=None):
             gh = GithubWebhook(minimal_hook_data, minimal_headers, logger)
             assert hasattr(gh, "repository")
@@ -138,7 +139,7 @@ class TestGithubWebhook:
     @patch("webhook_server.libs.github_api.get_api_with_highest_rate_limit")
     @patch("webhook_server.libs.github_api.get_github_repo_api")
     @patch("webhook_server.libs.github_api.get_repository_github_app_api")
-    @patch("webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix")
+    @patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix")
     def test_init_no_repository_objects(
         self,
         mock_color,
@@ -154,7 +155,7 @@ class TestGithubWebhook:
         mock_get_api.return_value = (Mock(), "token", "apiuser")
         mock_get_repo_api.return_value = None
         mock_get_app_api.return_value = None
-        mock_color.return_value = "repo"
+        mock_color.return_value = "test-repo"
         gh = GithubWebhook(minimal_hook_data, minimal_headers, logger)
         assert not hasattr(gh, "repository_by_github_app")
 
@@ -169,7 +170,7 @@ class TestGithubWebhook:
     @patch("webhook_server.libs.github_api.get_api_with_highest_rate_limit")
     @patch("webhook_server.libs.github_api.get_github_repo_api")
     @patch("webhook_server.libs.github_api.get_repository_github_app_api")
-    @patch("webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix")
+    @patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix")
     def test_process_ping_event(
         self,
         mock_color,
@@ -192,7 +193,7 @@ class TestGithubWebhook:
         mock_get_api.return_value = (Mock(), "token", "apiuser")
         mock_get_repo_api.return_value = Mock()
         mock_get_app_api.return_value = Mock()
-        mock_color.return_value = "repo"
+        mock_color.return_value = "test-repo"
         headers = minimal_headers.copy()
         headers["X-GitHub-Event"] = "ping"
         gh = GithubWebhook(minimal_hook_data, headers, logger)
@@ -414,7 +415,7 @@ class TestGithubWebhook:
     @patch("webhook_server.libs.github_api.get_api_with_highest_rate_limit")
     @patch("webhook_server.libs.github_api.get_github_repo_api")
     @patch("webhook_server.libs.github_api.get_repository_github_app_api")
-    @patch("webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix")
+    @patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix")
     @patch("webhook_server.libs.github_api.get_apis_and_tokes_from_config")
     def test_event_filtering_by_configuration(
         self,
@@ -435,19 +436,19 @@ class TestGithubWebhook:
         mock_get_api.return_value = (Mock(), "token", "apiuser")
         mock_get_repo_api.return_value = Mock()
         mock_get_app_api.return_value = Mock()
-        mock_color.return_value = "repo"
+        mock_color.return_value = "test-repo"
         mock_get_apis.return_value = []  # Return empty list to skip the problematic property code
 
         webhook = GithubWebhook(hook_data=minimal_hook_data, headers=minimal_headers, logger=Mock())
 
         # The test config includes pull_request in events list, so should be processed
-        assert webhook.repository_name == "repo"
+        assert webhook.repository_name == "test-repo"
 
     @patch("webhook_server.libs.github_api.get_repository_github_app_api")
     @patch("webhook_server.libs.github_api.get_api_with_highest_rate_limit")
     @patch("webhook_server.libs.github_api.get_github_repo_api")
     @patch("webhook_server.libs.github_api.get_repository_github_app_api")
-    @patch("webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix")
+    @patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix")
     @patch("webhook_server.libs.github_api.get_apis_and_tokes_from_config")
     def test_webhook_data_extraction(
         self,
@@ -468,14 +469,14 @@ class TestGithubWebhook:
         mock_get_api.return_value = (Mock(), "token", "apiuser")
         mock_get_repo_api.return_value = Mock()
         mock_get_app_api.return_value = Mock()
-        mock_color.return_value = "repo"
+        mock_color.return_value = "test-repo"
         mock_get_apis.return_value = []  # Return empty list to skip the problematic property code
 
         webhook = GithubWebhook(hook_data=minimal_hook_data, headers=minimal_headers, logger=Mock())
 
         # Verify data extraction
-        assert webhook.repository_name == "repo"
-        assert webhook.repository_full_name == "org/repo"
+        assert webhook.repository_name == "test-repo"
+        assert webhook.repository_full_name == "org/test-repo"
         assert webhook.github_event == "pull_request"
         assert webhook.x_github_delivery == "abc"
 
@@ -483,7 +484,7 @@ class TestGithubWebhook:
     @patch("webhook_server.libs.github_api.get_api_with_highest_rate_limit")
     @patch("webhook_server.libs.github_api.get_github_repo_api")
     @patch("webhook_server.libs.github_api.get_repository_github_app_api")
-    @patch("webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix")
+    @patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix")
     @patch("webhook_server.libs.github_api.get_apis_and_tokes_from_config")
     def test_api_rate_limit_selection(
         self,
@@ -504,7 +505,7 @@ class TestGithubWebhook:
         mock_get_api.return_value = (Mock(), "token", "apiuser")
         mock_get_repo_api.return_value = Mock()
         mock_get_app_api.return_value = Mock()
-        mock_color.return_value = "repo"
+        mock_color.return_value = "test-repo"
         mock_get_apis.return_value = []  # Return empty list to skip the problematic property code
 
         webhook = GithubWebhook(hook_data=minimal_hook_data, headers=minimal_headers, logger=Mock())
@@ -517,7 +518,7 @@ class TestGithubWebhook:
     @patch("webhook_server.libs.github_api.get_api_with_highest_rate_limit")
     @patch("webhook_server.libs.github_api.get_github_repo_api")
     @patch("webhook_server.libs.github_api.get_repository_github_app_api")
-    @patch("webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix")
+    @patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix")
     @patch("webhook_server.libs.github_api.get_apis_and_tokes_from_config")
     def test_repository_api_initialization(
         self,
@@ -538,7 +539,7 @@ class TestGithubWebhook:
         mock_get_api.return_value = (Mock(), "token", "apiuser")
         mock_get_repo_api.return_value = Mock()
         mock_get_app_api.return_value = Mock()
-        mock_color.return_value = "repo"
+        mock_color.return_value = "test-repo"
         mock_get_apis.return_value = []  # Return empty list to skip the problematic property code
 
         webhook = GithubWebhook(hook_data=minimal_hook_data, headers=minimal_headers, logger=Mock())
@@ -551,7 +552,7 @@ class TestGithubWebhook:
     @patch("webhook_server.libs.github_api.get_api_with_highest_rate_limit")
     @patch("webhook_server.libs.github_api.get_github_repo_api")
     @patch("webhook_server.libs.github_api.get_repository_github_app_api")
-    @patch("webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix")
+    @patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix")
     @patch("webhook_server.libs.github_api.get_apis_and_tokes_from_config")
     def test_init_failed_repository_objects(
         self,
@@ -571,7 +572,7 @@ class TestGithubWebhook:
         mock_get_api.return_value = (Mock(), "token", "apiuser")
         mock_get_repo_api.return_value = None
         mock_get_app_api.return_value = None
-        mock_color.return_value = "repo"
+        mock_color.return_value = "test-repo"
         mock_get_apis.return_value = []  # Return empty list to skip the problematic property code
         gh = GithubWebhook(minimal_hook_data, minimal_headers, logger)
         # Should have repository attribute but not repository_by_github_app
@@ -582,7 +583,7 @@ class TestGithubWebhook:
     @patch("webhook_server.libs.github_api.get_api_with_highest_rate_limit")
     @patch("webhook_server.libs.github_api.get_github_repo_api")
     @patch("webhook_server.libs.github_api.get_repository_github_app_api")
-    @patch("webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix")
+    @patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix")
     @patch("webhook_server.libs.github_api.get_apis_and_tokes_from_config")
     def test_add_api_users_to_auto_verified_and_merged_users(
         self,
@@ -602,7 +603,7 @@ class TestGithubWebhook:
         mock_get_api.return_value = (Mock(), "token", "apiuser")
         mock_get_repo_api.return_value = Mock()
         mock_get_app_api.return_value = Mock()
-        mock_color.return_value = "repo"
+        mock_color.return_value = "test-repo"
 
         def get_value_side_effect(value, *args, **kwargs):
             if value == "auto-verified-and-merged-users":
@@ -652,7 +653,7 @@ class TestGithubWebhook:
     @patch("webhook_server.libs.github_api.get_github_repo_api")
     @patch("webhook_server.libs.github_api.get_api_with_highest_rate_limit")
     @patch("webhook_server.libs.github_api.Config")
-    def test_get_reposiroty_color_for_log_prefix_new_color_file(
+    def test_prepare_log_prefix_with_color_file(
         self,
         mock_config,
         mock_get_api,
@@ -663,7 +664,7 @@ class TestGithubWebhook:
         minimal_headers,
         logger,
     ) -> None:
-        """Test _get_reposiroty_color_for_log_prefix with new color file."""
+        """Test prepare_log_prefix with repository color functionality."""
         with tempfile.TemporaryDirectory() as temp_dir:
             mock_config.return_value.repository = True
             mock_config.return_value.repository_local_data.return_value = {}
@@ -683,11 +684,11 @@ class TestGithubWebhook:
             mock_get_apis.return_value = [(mock_api1, "token1"), (mock_api2, "token2")]
 
             # Use a minimal_hook_data with repo name matching the test
-            hook_data = {"repository": {"name": "repo", "full_name": "repo"}}
+            hook_data = {"repository": {"name": "test-repo", "full_name": "test-repo"}}
             webhook = GithubWebhook(hook_data, minimal_headers, logger)
-            result = webhook._get_reposiroty_color_for_log_prefix()
+            result = webhook.prepare_log_prefix()
             # Call again to ensure file is read after being created
-            result2 = webhook._get_reposiroty_color_for_log_prefix()
+            result2 = webhook.prepare_log_prefix()
 
             # Check that a color file was created
             color_file = os.path.join(temp_dir, "log-colors.json")
@@ -699,7 +700,7 @@ class TestGithubWebhook:
     async def test_process_check_run_event(self, minimal_hook_data: dict, minimal_headers: dict, logger: Mock) -> None:
         """Test processing check run event."""
         check_run_data = {
-            "repository": {"name": "repo", "full_name": "org/repo"},
+            "repository": {"name": "test-repo", "full_name": "org/test-repo"},
             "check_run": {"name": "test-check", "head_sha": "abc123", "status": "completed", "conclusion": "success"},
         }
         headers = minimal_headers.copy()
@@ -780,10 +781,8 @@ class TestGithubWebhook:
                     with patch("webhook_server.libs.github_api.get_repository_github_app_api") as mock_get_app_api:
                         mock_get_app_api.return_value = Mock()
 
-                        with patch(
-                            "webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix"
-                        ) as mock_color:
-                            mock_color.return_value = "repo"
+                        with patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix") as mock_color:
+                            mock_color.return_value = "test-repo"
 
                             mock_pr = Mock()
                             mock_repo.get_pull.return_value = mock_pr
@@ -814,10 +813,8 @@ class TestGithubWebhook:
                     with patch("webhook_server.libs.github_api.get_repository_github_app_api") as mock_get_app_api:
                         mock_get_app_api.return_value = Mock()
 
-                        with patch(
-                            "webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix"
-                        ) as mock_color:
-                            mock_color.return_value = "repo"
+                        with patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix") as mock_color:
+                            mock_color.return_value = "test-repo"
 
                             mock_repo.get_pull.side_effect = GithubException(404, "Not found")
 
@@ -849,10 +846,8 @@ class TestGithubWebhook:
                     with patch("webhook_server.libs.github_api.get_repository_github_app_api") as mock_get_app_api:
                         mock_get_app_api.return_value = Mock()
 
-                        with patch(
-                            "webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix"
-                        ) as mock_color:
-                            mock_color.return_value = "repo"
+                        with patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix") as mock_color:
+                            mock_color.return_value = "test-repo"
 
                             mock_commit = Mock()
                             mock_repo.get_commit.return_value = mock_commit
@@ -881,10 +876,8 @@ class TestGithubWebhook:
                     with patch("webhook_server.libs.github_api.get_repository_github_app_api") as mock_get_app_api:
                         mock_get_app_api.return_value = Mock()
 
-                        with patch(
-                            "webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix"
-                        ) as mock_color:
-                            mock_color.return_value = "repo"
+                        with patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix") as mock_color:
+                            mock_color.return_value = "test-repo"
 
                             gh = GithubWebhook(minimal_hook_data, minimal_headers, logger)
                             gh.container_repository = "test-repo"
@@ -909,10 +902,8 @@ class TestGithubWebhook:
                     with patch("webhook_server.libs.github_api.get_repository_github_app_api") as mock_get_app_api:
                         mock_get_app_api.return_value = Mock()
 
-                        with patch(
-                            "webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix"
-                        ) as mock_color:
-                            mock_color.return_value = "repo"
+                        with patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix") as mock_color:
+                            mock_color.return_value = "test-repo"
 
                             gh = GithubWebhook(minimal_hook_data, minimal_headers, logger)
                             gh.container_repository = "test-repo"
@@ -940,10 +931,8 @@ class TestGithubWebhook:
                     with patch("webhook_server.libs.github_api.get_repository_github_app_api") as mock_get_app_api:
                         mock_get_app_api.return_value = Mock()
 
-                        with patch(
-                            "webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix"
-                        ) as mock_color:
-                            mock_color.return_value = "repo"
+                        with patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix") as mock_color:
+                            mock_color.return_value = "test-repo"
 
                             gh = GithubWebhook(minimal_hook_data, minimal_headers, logger)
                             gh.container_repository = "test-repo"
@@ -972,10 +961,8 @@ class TestGithubWebhook:
                     with patch("webhook_server.libs.github_api.get_repository_github_app_api") as mock_get_app_api:
                         mock_get_app_api.return_value = Mock()
 
-                        with patch(
-                            "webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix"
-                        ) as mock_color:
-                            mock_color.return_value = "repo"
+                        with patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix") as mock_color:
+                            mock_color.return_value = "test-repo"
 
                             gh = GithubWebhook(minimal_hook_data, minimal_headers, logger)
 
@@ -1000,10 +987,8 @@ class TestGithubWebhook:
                     with patch("webhook_server.libs.github_api.get_repository_github_app_api") as mock_get_app_api:
                         mock_get_app_api.return_value = Mock()
 
-                        with patch(
-                            "webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix"
-                        ) as mock_color:
-                            mock_color.return_value = "repo"
+                        with patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix") as mock_color:
+                            mock_color.return_value = "test-repo"
 
                             mock_response = Mock()
                             mock_response.status_code = 200
@@ -1035,10 +1020,8 @@ class TestGithubWebhook:
                     with patch("webhook_server.libs.github_api.get_repository_github_app_api") as mock_get_app_api:
                         mock_get_app_api.return_value = Mock()
 
-                        with patch(
-                            "webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix"
-                        ) as mock_color:
-                            mock_color.return_value = "repo"
+                        with patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix") as mock_color:
+                            mock_color.return_value = "test-repo"
 
                             mock_response = Mock()
                             mock_response.status_code = 400
@@ -1067,10 +1050,8 @@ class TestGithubWebhook:
                     with patch("webhook_server.libs.github_api.get_repository_github_app_api") as mock_get_app_api:
                         mock_get_app_api.return_value = Mock()
 
-                        with patch(
-                            "webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix"
-                        ) as mock_color:
-                            mock_color.return_value = "repo"
+                        with patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix") as mock_color:
+                            mock_color.return_value = "test-repo"
 
                             gh = GithubWebhook(minimal_hook_data, minimal_headers, logger)
 
@@ -1104,10 +1085,8 @@ class TestGithubWebhook:
                     with patch("webhook_server.libs.github_api.get_repository_github_app_api") as mock_get_app_api:
                         mock_get_app_api.return_value = Mock()
 
-                        with patch(
-                            "webhook_server.libs.github_api.GithubWebhook._get_reposiroty_color_for_log_prefix"
-                        ) as mock_color:
-                            mock_color.return_value = "repo"
+                        with patch("webhook_server.utils.helpers.get_repository_color_for_log_prefix") as mock_color:
+                            mock_color.return_value = "test-repo"
 
                             gh = GithubWebhook(minimal_hook_data, minimal_headers, logger)
 
